@@ -2,7 +2,7 @@
 
 #    test.py - tests for cfv (Command-line File Verify)
 #    Copyright (C) 2000-2013  Matthew Mueller <donut AT dakotacom DOT net>
-#    Copyright (C) 2018-2024  David Lisa Gnedt <cfv-project AT davizone DOT at>
+#    Copyright (C) 2018-2025  Lisa Gnedt <cfv-project AT davizone DOT at>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -1561,7 +1561,7 @@ def show_help_and_exit(err=None):
         print()
     print('usage: test.py [-i|-e] [--long] [--unit] [--exit-early] [cfv]')
     print(' -i      run tests internally')
-    print(' -e      launch seperate cfv process for each test')
+    print(' -e      launch separate cfv process for each test')
     print(' --long  include tests that may use large amounts of CPU or disk')
     print(' --unit  run only unittests, no integration tests')
     print(' --exit-early exit after first error')
@@ -1805,7 +1805,7 @@ def all_tests():
     test_generic(cfvcmd + ' -u -f test.md5 data* unchecked.dat', cfv_unv_test)
     test_generic(cfvcmd + ' -u -f test.md5 data* unchecked.dat test.md5', cfv_unv_test)
     test_generic(cfvcmd + r' -i -tcsv --fixpaths \\/ -Tu', lambda s, o: cfv_unv_test(s, o, None))
-    test_generic(cfvcmd + ' -T -t md5 -f non_existant_file', cfv_cferror_test)
+    test_generic(cfvcmd + ' -T -t md5 -f non_existent_file', cfv_cferror_test)
     test_generic(cfvcmd + ' -T -f ' + os.path.join('corrupt', 'missingfiledesc.par2'), cfv_cferror_test)
     test_generic(cfvcmd + ' -T -f ' + os.path.join('corrupt', 'missingmain.par2'), cfv_cferror_test)
     test_generic(cfvcmd + ' -T -m -f ' + os.path.join('corrupt', 'missingfiledesc.par2'), cfv_cferror_test)
